aboutsummaryrefslogtreecommitdiff
path: root/src/cflow.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/cflow.h')
-rw-r--r--src/cflow.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/cflow.h b/src/cflow.h
index 8779a68..7728ab7 100644
--- a/src/cflow.h
+++ b/src/cflow.h
@@ -85,8 +85,8 @@ typedef struct {
enum symbol_flag {
symbol_none,
- symbol_temp, /* Temporary symbol. Must be deleted after
- processing of the current module */
+ symbol_local, /* Unit-local symbol. Must be deleted after
+ processing current compilation unit */
symbol_parm, /* Parameter */
symbol_alias /* Alias to another symbol */
};

Return to:

Send suggestions and report system problems to the System administrator.